@@ -1,6 +1,6 @@
 #Plots the polygons in pal imported by get.paldata according
 #to the arcs in arc (value returned by get.arcdata)
-plotpal<-function(arc,pal, new=TRUE)
+plotpal<-function(arc,pal, new=TRUE, ...)
 {
 
 	#We only need the lists of arcs
@@ -22,6 +22,6 @@ plotpal<-function(arc,pal, new=TRUE)
 		}
 	}
 
-	plotarc(list(c(0),arc[arcs]), new=new)
+	plotarc(list(c(0),arc[arcs]), new=new, ...)
 
 }
