@@ -4,6 +4,8 @@
 #include<Rversion.h>
 #include<Rinternals.h>
 #include<Rdefines.h>
+#include"cpl_port.h" /*Needed to set endianness.*/
+
 
 #if R_VERSION < R_Version(1,2,0)
 #define STRING_ELT(x,i)		(STRING(x)[i])
@@ -14,12 +16,12 @@
 
 
 #ifdef WIN32 
-#define SLASH 92 // '\'
+#define SLASH 92 /* '\' */
 #else
-#define SLASH 47 // '/'
+#define SLASH 47 /* '/' */
 #endif
 
-#define PATH 257 //The length of an array containing a path
+#define PATH 257 /*The length of an array containing a path*/
 
 
 SEXP get_names_of_coverages(SEXP directory);
